#!/usr/bin/python

import socket, os, datetime

def log(filename, req, query, codes, unrecognized):
	req.add_common_vars()
	# determine ip
	remote_client_ip = req.connection.remote_ip
	# determine hostname
	hostname = req.connection.remote_host
	if hostname == None: hostname = 'localhost'
	# determine time
	str_time = datetime.datetime.now().strftime('%y%m%d%H%M%S')
	# determine user agent
	agent = ''
	if req.subprocess_env.has_key("HTTP_USER_AGENT"): agent = req.subprocess_env["HTTP_USER_AGENT"]
	# determine user allowed languages
	languages = ''
	if req.subprocess_env.has_key("HTTP_ACCEPT_LANGUAGE"): languages = req.subprocess_env["HTTP_ACCEPT_LANGUAGE"]
	# determine user allowed character sets
	charsets = ''
	if req.subprocess_env.has_key("HTTP_ACCEPT_CHARSET"): charsets = req.subprocess_env["HTTP_ACCEPT_CHARSET"]
	# write to file 
	str_out = '^'.join([str_time,remote_client_ip, hostname, query, ','.join(codes), unrecognized, agent, languages, charsets])
	os.system('echo "%s" >> %s' % (str_out, filename))



from urlparse import urlparse
from django.core.urlresolvers import resolve
from django.http import HttpResponseRedirect, Http404

def myview(request):
    next = request.META.get('HTTP_REFERER', None) or '/'
    response = HttpResponseRedirect(next)

    # Modify the request and response as required, e.g. change locale
    # and set corresponding locale cookie

    view, args, kwargs = resolve(urlparse(next)[2])
    kwargs['request'] = request
    try:
        view(*args, **kwargs)
    except Http404:
        return HttpResponseRedirect('/')
    return response



#!/usr/bin/python

import socket

www_log_filename = '/var/log/webapps/opentrep/www.log'
trep_log_filename = '/var/log/webapps/opentrep/opentrep.log'
tmp_trep_log_filename = '/var/log/webapps/opentrep/tmp_opentrep.log'

hostname = socket.gethostname()
main_name = hostname.split('.')[0]

traveldb_path = '/var/www/webapps/opentrep/trep/traveldb'
pyopentrep_path = '/var/www/webapps/opentrep/trep/lib64'




from flask import Flask
from flask_restful import Api, Resource
from flask import request
from flask_cors import CORS
import json
import pyopentrep, Travel_pb2

# Initialise the OpenTrep C++ library
# xapianDBPath = "/tmp/opentrep/xapian_traveldb"
# sqlDBConnStr = "/tmp/opentrep/sqlite_travel.db"
xapianDBPath = "/var/www/webapps/opentrep/trep/traveldb"
sqlDBType = "sqlite"
sqlDBConnStr = "/var/www/webapps/opentrep/trep/sqlite_travel.db"
#sqlDBType = "mysql"
#sqlDBConnStr = "db=trep_trep user=trep password=trep"
deploymentNb = 0
openTrepLibrary = pyopentrep.OpenTrepSearcher()
#queryAnswer = Travel_pb2.QueryAnswer()
initOK = openTrepLibrary.init (xapianDBPath, sqlDBType, sqlDBConnStr,
                               deploymentNb,
                               '/var/log/webapps/search/pyopentrep.log')

# Generate a query string with random place codes
def generateRandomString (nbOfDraws):
  # Randomly generate one place
  result = json.loads(openTrepLibrary.generate('J', nbOfDraws))
  return result


app = Flask("Search")
api = Api(app)
cors = CORS(app)

class georequest(Resource):
    def get(self):
        query_str = request.args.get('query')
        query_string_str = query_str.encode("utf8")
        result = json.loads(openTrepLibrary.search('J', query_string_str))
        return {'result': result}

class randomairportrequest(Resource):
    def get(self):
        return {'result':  generateRandomString(1) } ## It should return info on a random airport

class randomrouterequest(Resource):
    def get(self):
        return {'result': generateRandomString(3) } ## It should return info on a random route

api.add_resource(georequest, '/v1/geo')
api.add_resource(randomairportrequest, '/v1/randomairport')
api.add_resource(randomrouterequest, '/v1/randomroute')

if __name__ == '__main__':
    app.run(host="0.0.0.0",port=8090)



from piston.handler import BaseHandler
import json

#
class TrepHandler (BaseHandler):	
	def read (self, request, airportCodeURL=None):
		# Default values, corresponding to the default inventory dump
		# file loaded by the inventory server
		airportCode = 'LHR'

		# Extract the requested action from the query string (if any)
		airportCodeQuery = request.GET.get ('ac')

		# If the airport parameter is given within the URL (e.g.,
		# http://localhost:8000/api/display/place/SFO)
		# take it into account
		if airportCodeQuery: airportCode = airportCodeQuery

		# If the airport parameter is given as part of the query
		# string (e.g., http://localhost:8000/api/display/place?ac=LAX)
		# take it into account. It has the precedence over the 
		# parameter defined within the URL. That is, with
		# http://localhost:8000/api/display/place/RIO?ac=FRA
		# the following parameter would be kept: FRA
		if airportCodeURL: airportCode = airportCodeURL

		# Compose a JSON Python object with the parameters
		jsonAction = json.dumps ({'display': { 'airport_code': airportCode }})
		# print 'JSON serialised request: ', jsonAction

		# TODO: do not harcode the answer. Actually search for the airport instead.
		jsonMessage = jsonAction
		message = json.loads (jsonMessage)
		
		# print 'Received reply ', request, '[', jsonMessage, ']'
		#TESTING --- UNCOMMENT FOR NORMAL OPERATION ---		
		#return message
		print 'Message: ', message
		#REMOVE OR COMMENT FOR NORMAL OPERATION ---
		return message




from django.urls import re_path
from search import views

# Uncomment the next two lines to enable the admin:
# from django.contrib import admin
# admin.autodiscover()

app_name = 'search'

urlpatterns = [
    # Examples:
    # path(r'^$', 'opentrep.views.home', name='home'),
    # path(r'^opentrep/', include('opentrep.foo.urls')),

    # Uncomment the admin/doc line below to enable admin documentation:
    # path(r'^admin/doc/', include('django.contrib.admindocs.urls')),

    # Uncomment the next line to enable the admin:
    # path(r'^admin/', include(admin.site.urls)),

    #
    re_path(r'^$', views.index, name='index'),
]




from django.db import models

# Class corresponding to the ref_place_details database table
class Details (models.Model):
	code = models.CharField (max_length=3, primary_key=True)
	longitude = models.FloatField()
	latitude = models.FloatField()
	def __unicode__(self):
		return '%s (%d, %d)' % (self.code, self.latitude, self.longitude)

# Class corresponding to the ref_place_names database table,
# linked to the ref_place_details table
class Names (models.Model):
	code = models.ForeignKey (Details, db_column='code', primary_key=True)
	language_code = models.CharField (max_length=2, primary_key=True)
	classical_name = models.CharField (max_length=30)
	def __unicode__(self):
		return '%s (%s, %s)' % (self.code, self.language_code, self.classical_name)




from django.conf.urls.defaults import *

# Uncomment the next two lines to enable the admin:
# from django.contrib import admin
# admin.autodiscover()

urlpatterns = patterns('',
	#
	(r'^api/', include('opentrep.api.urls')),

    # Example:
    # (r'^opentrep/', include('opentrep.foo.urls')),

    # Uncomment the admin/doc line below to enable admin documentation:
    (r'^admin/doc/', include('django.contrib.admindocs.urls')),

    # Uncomment the next line to enable the admin:
    (r'^admin/', include('admin.site.urls')),
)




#
import math, re

#
def get_random_airport (openTrepLibrary, travelPB2):
  # OpenTREP
  result = openTrepLibrary.getRandom()
  # Protobuf
  place = travelPB2.Place()
  place.ParseFromString (result)
  return place

#
def get_lat_lon (place):
  return place.coord.latitude, place.coord.longitude

#
def get_lon_lat (place):
  return place.coord.longitude, place.coord.latitude

# 
def get_country_code (place):
  return place.country_code.code

# 
def get_country_name (place):
  return place.country_name

#
def get_city_code (place):
  return place.city_code.code

#
def get_city_names (place):
  return place.city_name_utf, place.city_name_ascii

#
def get_airport_names (place, nice=False):
  ugly_name_utf = place.name_utf
  ugly_name_ascii = place.city_name_ascii
  if not nice:
    return ugly_name_utf, ugly_name_ascii

  # "Ugly" names typically contain the country code (2 uppercase letters)
  # followed by a truncated repetition of the POR name. For instance:
  # - Cagnes Sur Mer FR Cagnes Sur M
  # - Antibes FR Antibes
  # We just truncate the name and keep the part before the country code.
  nice_name_utf = re.sub (r"(.*)([ ])([A-Z]{2})([ ])(.*)", "\\1", ugly_name_utf)
  nice_name_ascii = re.sub (r"(.*)([ ])([A-Z]{2})([ ])(.*)", "\\1",
                            ugly_name_ascii)
  return nice_name_utf, nice_name_ascii

#
def get_continent_code (place):
  return place.continent_code.code

#
def get_continent_name (place):
  return place.continent_name

#
def get_country_and_continent (place):
  return place.country_code.code, place.continent_code.code

# 
def great_circle_distance (lat1, lon1, lat2, lon2, degrees=True):
  if degrees:
    lat1 = lat1/180.0*math.pi
    lon1 = lon1/180.0*math.pi
    lat2 = lat2/180.0*math.pi
    lon2 = lon2/180.0*math.pi

    diameter = 12742.0
    lat_diff = (lat2-lat1) / 2.0
    lat_diff_sin = math.sin (lat_diff)
    lon_diff = (lon2-lon1) / 2.0
    lon_diff_sin = math.sin (lon_diff)
    lat_cos = math.cos (lat1) * math.cos (lat2)
    proj_dist = lat_diff_sin**2.0 + lat_cos * lon_diff_sin**2.0
    gcd = diameter * math.asin (math.sqrt (proj_dist))
  return gcd

#
def get_distance_km (place1, place2):
  lat1, lon1 = get_lat_lon (place1)
  lat2, lon2 = get_lat_lon (place2)
  dist = great_circle_distance (lat1, lon1, lat2, lon2)
  return dist

#
def get_local_local_flight_duration_hr (place1, place2):
  lat1, lon1 = get_lat_lon (place1)
  lat2, lon2 = get_lat_lon (place2)
  dist = great_circle_distance (lat1, lon1, lat2, lon2)
  travel_hr = 0.5 + dist/800.0
  time_diff_hr = (cit2['lon'] - cit1['lon']) / 15.0
  return travel_hr + time_diff_hr, unknown




import ez_setup
ez_setup.use_setuptools()
from setuptools import setup, find_packages
import sys

setup(
    name = "django-opentrep",
    version = '0.6.1',
    description = 'The Django-based Search for Travel Web application',
    packages = find_packages(),
    author = 'Denis.Arnaud',
    author_email = 'denis.arnaud_fedora@m4x.org',
    license = 'LGPL v2.1',
    keywords = 'opentrep, travel, intelligence, search, database, django',
    url = 'http://github.com/trep/opentrep',
    include_package_data = True,
    classifiers = [
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: LGPL License',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 2.4',
        'Programming Language :: Python :: 2.5',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: JavaScript',
        'Topic :: Internet :: WWW/HTTP :: WSGI :: Application',
    ],
    long_description = """The ``opentrep`` django app allows to easily
search for any travel-related POR (point of reference).

Setup
========

To the INSTALLED_APPS in your ``settings.py`` add entry ``'opentrep'``.

Usage
============

Examples below show how to use ``opentrep``

    import Travel_pb2
    import pyopentrep
    openTrepLibrary = pyopentrep.OpenTrepSearcher()
    initOK = openTrepLibrary.init ('/tmp/opentrep/xapian_traveldb', 'nodb', '', 0, 'pyopentrep.log')
    if initOK == False:
        errorMsg = 'Error: The OpenTrepLibrary cannot be initialised'
        raise Exception (errorMsg)

    result = openTrepLibrary.search ('J', 'nce sfo')
    print str(result)

"""
)



from django.conf.urls.defaults import *
from piston.resource import Resource
from api.handlers import TrepHandler

class CsrfExemptResource (Resource):
	"""Work around for the Cross-site request forgery (CSRF) issue

	See http://en.wikipedia.org/wiki/Cross-site_request_forgery.
	It is surely a bad idea to de-activate it for all the methods.
	See http://docs.djangoproject.com/en/dev/ref/contrib/csrf/
	"""
	def __init__ (self, handler, authentication = None):
		super (CsrfExemptResource, self).__init__ (handler, authentication)
		self.csrf_exempt = getattr (self.handler, 'csrf_exempt', True)

# 
display_resource = CsrfExemptResource (TrepHandler)

#
urlpatterns = patterns ('',
	(r'^(?:q=(?P<queryURL>.+))?$', display_resource),
	(r'^(?P<queryURL>.+)$', display_resource),
)




from django.urls import re_path
from searchsimple import views

# Uncomment the next two lines to enable the admin:
# from django.contrib import admin
# admin.autodiscover()

app_name = 'searchsimple'

urlpatterns = [
    # Examples:
    # url(r'^$', 'opentrep.views.home', name='home'),
    # url(r'^opentrep/', include('opentrep.foo.urls')),

    # Uncomment the admin/doc line below to enable admin documentation:
    # url(r'^admin/doc/', include('django.contrib.admindocs.urls')),

    # Uncomment the next line to enable the admin:
    # url(r'^admin/', include(admin.site.urls)),

    #
    re_path(r'^$', views.searchsimple),
    re_path(r'^(?P<query_string>[^/]+)/', views.searchsimple),
]





#!/bin/sh

#
AIRINV_HOSTNAME="localhost"
AIRINV_PORT=":8000"
API_URL_PREFIX="sim/airinv/api"
AIRINV_API_ACTION="display/inv"
AIRINV_BASE_URL="http://${AIRINV_HOSTNAME}${AIRINV_PORT}/${API_URL_PREFIX}/${AIRINV_API_ACTION}"
TMP_FILE="found.tmp"

# Check whether curl is installed
`type curl` > ${TMP_FILE} 2>&1
FOUND=`grep -qi "not found" ${TMP_FILE} && echo "No"`
rm -f ${TMP_FILE}

if [ "${FOUND}" = "No" ]
then
  echo
  echo "curl is not installed on your system."
  echo "Please ask your administrator to install it."
  echo
  exit -1
fi

#
displayInventory() {
    echo "Trying with the classical (GET) query string:"
    curl "${AIRINV_BASE_URL}?ac=${AIRLINE_CODE}&fn=${FLIGHT_NUMBER}&dd=${DEPARTURE_DATE}"
    echo
    echo "Trying with the typical Django URL:"
    curl "${AIRINV_BASE_URL}/${AIRLINE_CODE}/${FLIGHT_NUMBER}/${DEPARTURE_DATE}"
    echo
}

#
AIRLINE_CODE="SV"
FLIGHT_NUMBER="5"
DEPARTURE_DATE="2010-Mar-11"
displayInventory




"""opentrep URL Configuration

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/2.2/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  path('', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  path('', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.urls import include, path
    2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
"""
#from django.contrib import admin
from django.urls import path, include
from search import views

app_name = "opentrep"

#handler404 = 'search.views.custom_404_view'
#handler500 = 'search.views.custom_500_view'

urlpatterns = [
    # Catch-all
    path('', include('search.urls')),
    # url(r'^$', views.index, name='home'),

    # The following two directives do not match if the catch-all directive
    # above is active (not commented)
    path('searchsimple/', include('searchsimple.urls')),
    path('search/', include('search.urls')),
]




from django.shortcuts import render
from django.http import Http404
import sys, getopt, os
import simplejson as json
sys.path.append ('/var/www/webapps/opentrep/trep/lib')
sys.path.append ('/var/www/webapps/opentrep/trep/lib/python/opentrep')
import pyopentrep
import Travel_pb2

def searchsimple (request, query_string = None):
    #
    if query_string is None:
        query_string = 'rio de janero sna francisco'

    # Initialise the OpenTrep C++ library
    xapianDBPath = "/tmp/opentrep/traveldb"
    openTrepLibrary = pyopentrep.OpenTrepSearcher()
    initOK = openTrepLibrary.init (xapianDBPath, 'nodb', '', 0, 'pyopentrep.log')
    if initOK == False:
        errorMsg = 'Error: The OpenTrepLibrary cannot be initialised'
        raise Http404

    # Call the underlying OpenTREP library
    query_string_str = str(query_string)
    result = openTrepLibrary.search ('P', query_string_str)

    # Protobuf
    placeList = Travel_pb2.PlaceList()
    placeList.ParseFromString (result)

    #
    interpretedString = ''

    # DEBUG
    #print 'Result: ' + str(placeList)

    # Free the OpenTREP library resource
    openTrepLibrary.finalize()

    #
    return render (request, 'searchsimple/index.html',
                        {'place_list': placeList.place,
                         'query_string': query_string})




from flask import Flask
from flask_restful import Api, Resource
from flask import request
from flask_cors import CORS
import pyopentrep, Travel_pb2

def checkCorrectSyntax(query):
    elements = query.split(" ")
    good = all(len(e)==3 for e in elements)
    return good

def checkCities(places):
    codes = []
    for place in places:
        try:
            codes.append({'code':"MAD"})
        except KeyError, e:
            return None
    return codes

app = Flask("Search")
api = Api(app)
cors = CORS(app)

class georequest(Resource):
    def get(self):
        query = request.args.get('query')
        print query
        if checkCorrectSyntax(query):
            places = query.split(" ")
            codes = checkCities(places)
            if codes is not None:
                return {'result': codes}
            else:
                return {'result': [], 'error': "One of the codes was not found"}
        else:
            return {'result': [], 'error': "Incorrect Syntax"}

class randomairportrequest(Resource):
    def get(self):
        return {'result': {'code':"MAD"}} ## It should return info on a random airport

class randomrouterequest(Resource):
    def get(self):
        return {'result': {'code':"MAD"}} ## It should return info on a random route

api.add_resource(georequest, '/v1/geo')
api.add_resource(randomairportrequest, '/v1/randomairport')
api.add_resource(randomrouterequest, '/v1/randomroute')

if __name__ == '__main__':
    app.run(host="0.0.0.0",port=8090)



from sys import path
from os import environ
from piston.handler import BaseHandler
import simplejson

# Retrieve the OpenTrep parameters
traveldb_path = environ.get ('TREP_TRAVELDB', failobj='/tmp/opentrep/traveldb')
trep_log_path = environ.get ('TREP_LOG', failobj='django_trep.log')
trep_lib_dir = environ.get ('TREP_LIB', failobj='/usr/lib')

# The first time a request is handled by Django (after that latter has been
# started), the OpenTrep library has to be initialised
path.append (trep_lib_dir)

import pyopentrep
openTrepLibrary = pyopentrep.OpenTrepSearcher()
openTrepLibrary.init (traveldb_path, 'nodb', '', 0, trep_log_path)

#
class TrepHandler (BaseHandler):	
	def read (self, request, queryURL=None):
		# Default values
		query = 'SFO JFK'

		# Extract the requested action from the query string (if any)
		queryQuery = request.GET.get ('q')

		# If the query parameters are given within the URL (e.g.,
		# http://localhost:8000/trep/api/SFO)
		# take them into account
		if queryQuery: query = queryQuery

		# If the query parameters are given as part of the query
		# string (e.g., http://localhost:8000/trep/api?q=SFO)
		# take them into account. They have the precedence over the 
		# parameters defined within the URL. That is, with
		# http://localhost:8000/trep/api/LAX?q=SFO
		# the following parameters would be kept: LAX
		if queryURL: query = queryURL

		#
		query = str(query)

		# Call the underlying Trep library, which returns JSON-formatted
		# list of POR (points of reference).
		opentrepOutputFormat = 'J'
		jsonMessage = openTrepLibrary.search (opentrepOutputFormat, query)
		response = simplejson.loads (jsonMessage)	
		
		# print 'Received reply ', request, '[', jsonMessage, ']'
		#TESTING --- UNCOMMENT FOR NORMAL OPERATION ---
		return response
		#return response
		#REMOVE OR COMMENT FOR NORMAL OPERATION ---




#!/usr/bin/env python
# -*- coding: utf-8 -*-

query = u'ЙЦУКЕНГШЩЗХЪ ФЫВАПРОЛДЖЭ ЯЧСМИТЬБЮ Ё ЇІЄ'
query_input = raw_input()
if query_input != '':
	query = unicode(query_input,encoding='utf-8')

print 'Original query: ' + query
print 'Lower-cased query: ' + query.lower()
print 'Upper-cased query: ' + query.upper() + '\n'




#!/usr/bin/env python

import os, json
import pytest
import pyopentrep


def test_e2e_simple():
    """
    Test initializing and searching with OpenTrepLibrary
    """
    openTrepLibrary = pyopentrep.OpenTrepSearcher()
    initOK = openTrepLibrary.init(
        "/tmp/opentrep/xapian_traveldb",
        "sqlite",
        "/tmp/opentrep/sqlite_travel.db",
        0,
        "pyopentrep.log",
    )
    nce_sfo_query = "nce sfo"
    nce_sfo_result = penTrepLibrary.search("S", nce_sfo_query)
    assert nce_sfo_result, (
        f"The results for the query ({nce_sfo_query}, are not as expected.\n"
        f"Expected: 'NCE/0,SFO/0' expected) - Got: '{nce_sfo_result}'"
    )



#!/usr/bin/env python

import sys

# Parser helpers
def getMain(locations):
	return locations[:3].upper()

# Default result string
defaultResultString = 'yvr:xea/98-xtw/87,sfo/100,led:dft:htl/96;niznayou'

# If no result string was supplied as arguments of the command-line,
# ask the user for some
resultString = ','.join(sys.argv[1:])
if resultString == '' : resultString = defaultResultString

# Function to parse the result string
def parseResultString(iResultString):
    form_value, unrecognized = '', ''
    msg = '(parsing successful)'
    str_matches = iResultString
    locations = []
    alter_locations = []

    if ';' in str_matches:
        str_matches, unrecognized = str_matches.split(';')
        msg = '(unrecognized: %s)' % unrecognized
    str_value = unrecognized

    if str_matches != '':
        alter_locations = str_matches.split(',')
        locations = [getMain(x) for x in alter_locations]

    print 'locations: ', locations
    print 'alter_locations: ', alter_locations

    idx1 = 0
    while idx1 != len(alter_locations):

#       print 'Before - alter_locations['+str(idx1)+']: ', alter_locations[idx1]
        alter_locations[idx1] = alter_locations[idx1].split('-')
#       print 'After - alter_locations['+str(idx1)+']: ', alter_locations[idx1], alter_locations

        idx2 = 0
        while idx2 != len(alter_locations[idx1]):

            alter_locations[idx1][idx2] = alter_locations[idx1][idx2].split(':')

            idx3 = 0
            while idx3 != len(alter_locations[idx1][idx2]):

                alter_locations[idx1][idx2][idx3] = alter_locations[idx1][idx2][idx3].split('/')
                idx3 += 1

            idx2 += 1

        idx1 += 1
				
#    codes = [x.upper() for x in alter_locations]
#    if len(codes) > 0: form_value = ' '.join(codes)
    if str_value != '': form_value += ' ' + str_value

    print 'After - alter_locations: ', alter_locations

    print 'Result: ' + ' '.join(locations) + ' ' + msg + ':'
    return form_value

# Main
print 'Before: ' + resultString
resultString = parseResultString(resultString)
print 'After: ' + resultString



#!/usr/bin/env python

#
#   AirInv client in Python
#   Connects REQ socket to tcp://localhost:5555
#   Sends JSON-ified parameters of a flight-date to display to the AirInv 
#   server, and expects the full JSON-ified details for that given flight-date.
#
import getopt, sys, json, zmq

#------------------------------------------------------------------------------	
def usage():
    print
    print
    print "-h, --help               : outputs help and quits"
    print "-a <airline_code>        : Code of the owner airline"
    print "-f <flight_number>       : Number of the flight to display"
    print "-d <departure_date>      : Departure date of the flight to display"
    print "[[[<airline_code>] [<flight_number>]] [<departure_date>]] : parameters of the flight to display (if not already provided as option)"
    print
	
#------------------------------------------------------------------------------	
def handle_opt():
    try:
        opts, args = getopt.getopt (sys.argv[1:], "h:a:f:d:", ["help", "airline_code", "flight_number", "departure_date"])
    except getopt.GetoptError, err:
        # Will print something like "option -z not recognized"
        print str(err)
        usage()
        sys.exit(2)
	
    # Default options/parameters
    airlineCode = 'SV'
    flightNumber = 5
    departureDate = '2010-Mar-11'

    # Handling parameters
    if len (args) >= 1:
        airlineCode = args[0]
    if len (args) >= 2:
        flightNumber = args[1]
    if len (args) >= 3:
        departureDate = args[2]

    # Handling options
    for optionName, optionValue in opts:
        if optionName in ("-h", "--help"):
            usage()
            sys.exit()
        elif optionName in ("-a", "--airline_code"):
            airlineCode = optionValue
        elif optionName in ("-f", "--flight_number"):
            flightNumber = optionValue
        elif optionName in ("-d", "--departure_date"):
            departureDate = optionValue
        else:
            assert False, "Unhandled option"

    return airlineCode, flightNumber, departureDate

#------------------------------------------------------------------------------	
def main():

    # Parse command options
    airlineCode, flightNumber, departureDate = handle_opt()
    jsonAction = {'flight_date': { 'departure_date': departureDate, 'airline_code': airlineCode, 'flight_number': flightNumber }}
    jsonActionString = json.dumps (jsonAction)

    #  Socket to talk to server
    print "Connecting to hello world server..."
    context = zmq.Context()
    socket = context.socket (zmq.REQ)
    socket.connect ("tcp://localhost:5555")
    print "... done"

    #  Send the flight-date parameters to the AirInv server
    print "Requesting flight-date ", jsonActionString, " from the AirInv server..."
    socket.send (jsonActionString)
    
    #  Get the flight-date details from the AirInv server
    flightDateDetails = socket.recv()
    print "... received reply: '", flightDateDetails, "'"


#-------------------------------------------------------------------------------
if __name__ == "__main__":
    main()




from django.shortcuts import render
from django.http import Http404
from django.http import HttpResponseRedirect, HttpResponse
from django.urls import reverse
from django.utils.encoding import smart_text, smart_bytes
from google.protobuf import text_format
import sys, getopt, os, math, codecs
import simplejson as json
import logging
# Potentially add the following two pathes to the PYTHONPATH environment variable
# 1. Path to the OpenTrep C++ library of the Python wrapper (pyopentrep.so)
# 2. Path to the OpenTrep ProtoBuf stubs (Travel_pb2.py)
import pyopentrep, Travel_pb2

# 404 - Page not found
def custom_404_view (request):
  #errorMsg = 'Error: page not found'
  return render (request, 'search/404.html', {'error_msg': '',
                                              'request_path': request.path})

# 500 - Server error
def custom_500_view (request):
  #errorMsg = 'Error: Standard Django error'
  return render (request, 'search/500.html', {'error_msg': '',
                                              'request_path': request.path})


# Calculate the great circle distance, given the geographical coordinates
def great_circle_distance (lat1, lon1, lat2, lon2, degrees=True):
  if degrees:
    lat1 = lat1 / 180.0 * math.pi
    lon1 = lon1 / 180.0 * math.pi
    lat2 = lat2 / 180.0 * math.pi
    lon2 = lon2 / 180.0 * math.pi

    diameter = 12742.0
    lat_diff = (lat2-lat1) / 2.0
    lat_diff_sin = math.sin (lat_diff)
    lon_diff = (lon2-lon1) / 2.0
    lon_diff_sin = math.sin (lon_diff)
    lat_cos = math.cos (lat1) * math.cos (lat2)
    proj_dist = lat_diff_sin**2.0 + lat_cos * lon_diff_sin**2.0
    gcd = diameter * math.asin (math.sqrt (proj_dist))
  return gcd

# Calculate the great circle distance of two POR (points of reference) entries
def get_distance_km (place1, place2):
  lat1, lon1 = place1.coord.latitude, place1.coord.longitude
  lat2, lon2 = place2.coord.latitude, place2.coord.longitude
  dist = great_circle_distance (lat1, lon1, lat2, lon2)
  return dist

# Calculate the flight elapsed time
def get_local_local_flight_duration_hr (place1, place2):
  lat1, lon1 = place1.coord.latitude, place1.coord.longitude
  lat2, lon2 = place2.coord.latitude, place2.coord.longitude
  dist = great_circle_distance (lat1, lon1, lat2, lon2)
  travel_hr = 0.5 + dist/800.0
  time_diff_hr = (cit2['lon'] - cit1['lon']) / 15.0
  return travel_hr + time_diff_hr

# Initialise the OpenTrep library
def initOpenTrep():
  # Initialise the OpenTrep C++ library
  # xapianDBPath = "/tmp/opentrep/xapian_traveldb"
  # sqlDBConnStr = "/tmp/opentrep/sqlite_travel.db"
  xapianDBPath = "/var/www/webapps/opentrep/trep/traveldb"
  sqlDBType = "sqlite"
  sqlDBConnStr = "/var/www/webapps/opentrep/trep/sqlite_travel.db"
  #sqlDBType = "mysql"
  #sqlDBConnStr = "db=trep_trep user=trep password=trep"
  deploymentNb = 0
  openTrepLibrary = pyopentrep.OpenTrepSearcher()
  initOK = openTrepLibrary.init (xapianDBPath, sqlDBType, sqlDBConnStr,
                                 deploymentNb,
                                 '/var/log/webapps/search/pyopentrep.log')
  return initOK, openTrepLibrary

# Extract the answer from the resulting ProtoBuf
def extractAnswer (result):
  # Unserialise the Protobuf
  queryAnswer = Travel_pb2.QueryAnswer()
  queryAnswer.ParseFromString (result)

  # Status
  okStatus = queryAnswer.ok_status

  return okStatus, queryAnswer

# Generate a query string with random place codes
def generateRandomString (nbOfDraws):
  # Initialise the OpenTrep C++ library
  initOK, openTrepLibrary = initOpenTrep()
  if initOK == False:
    return initOK, False, ''

  # Randomly generate one place
  result = openTrepLibrary.generateToPB (nbOfDraws)

  # Extract the answer
  okStatus, queryAnswer = extractAnswer (result)

  # List of places
  placeList = queryAnswer.place_list
  place_list = [place.tvl_code.code for place in placeList.place]

  # Build the query string
  query_string = ' '.join(place_list)

  return initOK, okStatus, query_string


# Extract the parameters from the incoming request
def extract_params (request, query_string = ''):
  #
  result = False
  place_list = None
  zoom_level = 5
  map_type_value = 'HYBRID'

  # Try with GET
  search_form = request.GET

  # Detect the required action
  if 'show_airport' in search_form:
    # Randomly generate one place
    initOK, okStatus, query_string = generateRandomString (1)
    if initOK == False:
      errorMsg = 'Error: The OpenTrepLibrary cannot be initialised'
      return render (request, 'search/500.html', {'error_msg': errorMsg})
    elif okStatus == False or query_string == '':
      errorMsg = 'Error: The OpenTrepLibrary cannot generate ' + str(nbOfDraws) + ' places'
      return render (request, 'search/500.html', {'error_msg': errorMsg})
    result = True

  elif 'show_itinerary' in search_form:
    # Randomly generate three places
    initOK, okStatus, query_string = generateRandomString (3)
    if initOK == False:
      errorMsg = 'Error: The OpenTrepLibrary cannot be initialised'
      return render (request, 'search/500.html', {'error_msg': errorMsg})
    elif okStatus == False or query_string == '':
      errorMsg = 'Error: The OpenTrepLibrary cannot generate ' + str(nbOfDraws) + ' places'
      return render (request, 'search/500.html', {'error_msg': errorMsg})
    result = True

  elif 'q' in search_form:
    query_string = search_form['q']
    result = True

  # Detect the Google Map parameters (if any)
  if 'z' in search_form:
    zoom_level = search_form['z']
  if 'mt' in search_form:
    map_type_value = search_form['mt']

  # Try with POST
  search_form = request.POST

  # Detect the required action
  if 'q' in search_form:
    query_string = search_form['q']
    result = True

  elif 'show_airport' in search_form:
    # Randomly generate one place
    initOK, okStatus, query_string = generateRandomString (1)
    if initOK == False:
      errorMsg = 'Error: The OpenTrepLibrary cannot be initialised'
      return render (request, 'search/500.html', {'error_msg': errorMsg})
    elif okStatus == False or query_string == '':
      errorMsg = 'Error: The OpenTrepLibrary cannot generate ' + str(nbOfDraws) + ' places'
      return render (request, 'search/500.html', {'error_msg': errorMsg})
    result = True
  elif 'show_itinerary' in search_form:
    # Randomly generate three places
    initOK, okStatus, query_string = generateRandomString (3)
    if initOK == False:
      errorMsg = 'Error: The OpenTrepLibrary cannot be initialised'
      return render (request, 'search/500.html', {'error_msg': errorMsg})
    elif okStatus == False or query_string == '':
      errorMsg = 'Error: The OpenTrepLibrary cannot generate ' + str(nbOfDraws) + ' places'
      return render (request, 'search/500.html', {'error_msg': errorMsg})
    result = True

  # Detect the Google Map parameters (if any)
  if 'z' in search_form:
    zoom_level = search_form['z']
  if 'mt' in search_form:
    map_type_value = search_form['mt']

  #
  return query_string, result, place_list, zoom_level, map_type_value

# Calculate the corrected query string, based on the corrected keywords for
# every place
def calculate_corrected_query_string (place_list):
  corrected_query_string = ''
  idx = 0
  for place in place_list:
    if idx != 0:
      corrected_query_string += ' '
    corrected_query_string += ' '.join(place.corrected_keyword_list.word)
    idx += 1

  return corrected_query_string

#
def index (request):
  # Extract the parameters from the incoming request
  query_string, result, place_list, zoom_level, map_type_value = extract_params (request, query_string='')

  if query_string == '':
    #
    return render (request, 'search/index.html', {
        'place_list': None,
        'place_pair_list': [{'dep': None, 'arr': None, 'dist': '0'}],
        'nb_of_places': 0,
        'dist_total': '0',
        'unmatched_keyword_list': None, 'n_unmatched_kw': 0,
        'query_string': query_string,
        'corrected_query_string': query_string,
        'coord_for_GMap_center': '',
        'zoom_level': zoom_level, 'map_type_value': map_type_value})
  else:
    # Delegate the call to the display view
    return display (request, query_string, zoom_level, map_type_value)

#
def display (request, query_string = '',
             zoom_level = 5, map_type_value = 'HYBRID'):
  # Logging
  logger = logging.getLogger ('django.request')
  logger.info (str(request))
  logger.info ('Query string: "' + query_string + '"')

  #
  if query_string == '':
    return HttpResponseRedirect (reverse ('search:index'))
        

  # Initialise the OpenTrep C++ library
  initOK, openTrepLibrary = initOpenTrep()
  if initOK == False:
    errorMsg = 'Error: The OpenTrepLibrary cannot be initialised'
    logger.error (errorMsg)
    return render (request, 'search/500.html', {'error_msg': errorMsg})

  # Call the underlying C++ OpenTREP library. The input string is converted
  # into UTF-8 (from Unicode), so that the OpenTREP library be happy with it.
  #query_string_str = smart_bytes (query_string, encoding='utf-8',
  #                                strings_only=True, errors='strict')
  result = openTrepLibrary.searchToPB (query_string)

  # Extract the answer
  okStatus, queryAnswer = extractAnswer (result)

  # Query status
  if okStatus == False:
    errorMsg = 'Error in the OpenTREP library: ' + queryAnswer.error_msg.msg
    logger.error (errorMsg)
    return render (request, 'search/500.html', {'error_msg': errorMsg})

  # List of places
  placeList = queryAnswer.place_list

  # List of unmatched keywords
  unmatchedKeywordList = queryAnswer.unmatched_keyword_list

  #
  interpretedString, msg = '', ''
  coord_for_GMap_center = {'lat': 10, 'lon': 0}

  # DEBUG
  logger.debug ('Result: ' + str(placeList))

  # Free the OpenTREP library resource
  openTrepLibrary.finalize()

  # Calling appropriate program (nothing, coordinates, or distance)
  place_list = placeList.place
  n_airports = len (place_list)
  place_pair_list = []
  dist_total = 0
  unmatched_keyword_list = unmatchedKeywordList.word
  n_unmatched_kw = len (unmatched_keyword_list)

  ##
  # No airport (=> no map)
  ##
  if n_airports == 0:
    if (result == True):
      msg += 'Your entry ("%s") was not recognised:<br>' % query_string_str
      msg += 'Enter a three-letter code or the name of an airport or city to find out its coordinates (e.g., JFK, or Rio de Janeiro)<br>'
      msg += 'Enter a sequence of two three-letter place_list or names to find out the distance between those airports (e.g., JFK CDG Tokyo)'

  ##
  # A single airport => a map with a single marker
  ##
  elif n_airports == 1:
    place = place_list[0]
    place_pair_list = [{'dep': place, 'arr': None, 'dist': '0'}]
    coord_for_GMap_center = {'lat': place.coord.latitude,
                             'lon': place.coord.longitude}

  ##
  # Several airports => a map with several paths (and markers)
  ##
  elif n_airports >= 2:
    # Iterate on two lists, one browsing elements [1, N-1],
    # the other browsing the elements [2, N]
    place_list_front = place_list[:-1]
    place_list_second = place_list[1:]
    for (place1, place2) in zip (place_list_front, place_list_second):
      dist = get_distance_km (place1, place2)
      dist_total += dist
      place_pair_list.append ({'dep': place1, 'arr': place2, 
                               'dist': '%d' % dist})

  # Calculate the corrected query string
  corrected_query_string = calculate_corrected_query_string (place_list)

  #
  logger.info ('Query string: "' + query_string
               + '", corrected query string: "' + corrected_query_string
               + '", unmatched keywords: "' + str(unmatched_keyword_list) + '"')
  logger.info ('Place list: ' + text_format.MessageToString (placeList))
  return render (request, 'search/display.html', {
      'place_list': place_list, 'place_pair_list': place_pair_list,
      'nb_of_places': n_airports,
      'dist_total': '%d' % dist_total,
      'unmatched_keyword_list': unmatched_keyword_list,
      'n_unmatched_kw': n_unmatched_kw,
      'query_string': query_string,
      'corrected_query_string': corrected_query_string,
      'coord_for_GMap_center': coord_for_GMap_center,
      'zoom_level': zoom_level, 'map_type_value': map_type_value})




import socket, os, datetime

def log (filename, req, query):
	req.add_common_vars()

	# Determine IP address
	remote_client_ip = req.connection.remote_ip

	# Determine hostname
	hostname = req.connection.remote_host
	if hostname == None:
		hostname = 'localhost'

	# Determine current time
	str_time = datetime.datetime.now().strftime('%y%m%d%H%M%S')

	# Determine user agent (browser type)
	agent = ''
	if req.subprocess_env.has_key("HTTP_USER_AGENT"):
		agent = req.subprocess_env["HTTP_USER_AGENT"]

	# Determine user allowed languages
	languages = ''
	if req.subprocess_env.has_key("HTTP_ACCEPT_LANGUAGE"):
		languages = req.subprocess_env["HTTP_ACCEPT_LANGUAGE"]

	# Determine user allowed character sets
	charsets = ''
	if req.subprocess_env.has_key("HTTP_ACCEPT_CHARSET"):
		charsets = req.subprocess_env["HTTP_ACCEPT_CHARSET"]

	# Write to log file
	str_out = '^'.join ([str_time,remote_client_ip, hostname, query,
			     agent, languages,
			     charsets])
	os.system ('echo "%s" >> %s' % (str_out, filename))




"""
Django settings for opentrep project.

Generated by 'django-admin startproject' using Django 2.2.9.

For more information on this file, see
https://docs.djangoproject.com/en/2.2/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/2.2/ref/settings/
"""

import os

# Build paths inside the project like this: os.path.join(BASE_DIR, ...)
BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))


# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/2.2/howto/deployment/checklist/

# SECURITY WARNING: keep the secret key used in production secret!
SECRET_KEY = '21fgr@lu4%kv0jbq)w08!^by_nh#7@z(0qv4i&#f^s!(nlp=+k'

# SECURITY WARNING: don't run with debug turned on in production!
DEBUG = False

ADMINS = (
    ('Transport Search', 'site@transport-search.org'),
)

ALLOWED_HOSTS = ['.search-travel.org',
 '.search-airport.com', '.search-airport.net', '.search-airport.org',
 '.search-airports.com', '.search-airports.fr', '.search-airports.net',
 '.search-airports.org', '.searchairport.net', '.searchairport.org',
 '.searchairports.fr', '.searchairports.net', '.searchairports.org',
 '.find-airport.com', '.find-airport.fr', '.find-airport.net',
 '.find-airport.org', '.find-airports.com', '.find-airports.fr',
 '.find-airports.org', '.find-airports.net', '.findairport.fr',
 '.findairport.net', '.findairport.org', '.findairports.fr',
 '.findairports.org', '.search4travel.org', '.transport-intelligence.com',
 '.transport-search.org', 
 '149.202.75.38', '147.135.185.242', '10.30.1.105',
 '91.121.51.176', '87.98.129.227', '87.98.137.123']


# Application definition

INSTALLED_APPS = [
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'opentrep',
    'searchsimple',
    'search',
]

MIDDLEWARE = [
    'django.middleware.security.SecurityMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
]

ROOT_URLCONF = 'opentrep.urls'

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [
            '/var/www/webapps/search/search/templates/search',
            ],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
]

WSGI_APPLICATION = 'opentrep.wsgi.application'


# Database
# https://docs.djangoproject.com/en/2.2/ref/settings/#databases

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': os.path.join(BASE_DIR, 'db.sqlite3'),
    }
}


# Password validation
# https://docs.djangoproject.com/en/2.2/ref/settings/#auth-password-validators

AUTH_PASSWORD_VALIDATORS = [
    {
        'NAME': 'django.contrib.auth.password_validation.UserAttributeSimilarityValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.MinimumLengthValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.CommonPasswordValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.NumericPasswordValidator',
    },
]


# Internationalization
# https://docs.djangoproject.com/en/2.2/topics/i18n/

LANGUAGE_CODE = 'en-us'

TIME_ZONE = 'Europe/Paris'

USE_I18N = True

USE_L10N = True

USE_TZ = True


# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/2.2/howto/static-files/

STATIC_URL = '/static/'

# A sample logging configuration. The only tangible logging
# performed by this configuration is to send an email to
# the site admins on every HTTP 500 error when DEBUG=False.
# See https://docs.djangoproject.com/en/dev/topics/logging for
# more details on how to customize your logging configuration.
LOGGING = {
    'version': 1,
    'disable_existing_loggers': False,
    'filters': {
        'require_debug_false': {
            '()': 'django.utils.log.RequireDebugFalse'
        }
    },
    'handlers': {
        'mail_admins': {
            'level': 'ERROR',
            'filters': ['require_debug_false'],
            'class': 'django.utils.log.AdminEmailHandler'
        },
        'file': {
            'level': 'DEBUG',
            'class': 'logging.FileHandler',
            'filename': '/var/log/webapps/search/django.log',
        }
    },
    'loggers': {
        'django.request': {
            'handlers': ['file', 'mail_admins'],
            'level': 'INFO',
            'propagate': True,
        },
    }
}





#!/usr/bin/env python

import sys
sys.path.append('.libs')
import libpyboost

myWorld = libpyboost.World()
myWorld.add('Bonjour', 5)
myWorld.add('Hello', 7)
myWorld.add('Gruss Gott', 5)

#MsgList=myWorld.getMsgList()
#IDList=myWorld.getIDList()

#print ', '.join(['%s: %s' % (msg, id) for (msg, id) in zip(MsgList, IDList)])

a = myWorld.toSimpleString().split(',')
print '^'.join(a[::-1])



from django.db import models

# Class corresponding to the geoname database table
class POR (models.Model):
    geonameid = models.IntegerField (db_column='geonameid', primary_key=True)
    name = models.CharField (max_length=200, null=True, blank=True)
    asciiname = models.CharField (max_length=200, null=True, blank=True)
    alternatenames = models.CharField (max_length=4000, null=True, blank=True)
    latitude = models.DecimalField (max_digits=10, decimal_places=7, null=True,
                                    blank=True)
    longitude = models.DecimalField (max_digits=10, decimal_places=7, null=True,
                                     blank=True)
    fclass = models.CharField (max_length=1, null=True, blank=True)
    fcode = models.CharField (max_length=10, null=True, blank=True)
    country = models.CharField (max_length=2, null=True, blank=True)
    cc2 = models.CharField (max_length=60, null=True, blank=True)
    admin1 = models.CharField (max_length=20, null=True, blank=True)
    admin2 = models.CharField (max_length=80, null=True, blank=True)
    admin3 = models.CharField (max_length=20, null=True, blank=True)
    admin4 = models.CharField (max_length=20, null=True, blank=True)
    population = models.IntegerField (null=True, blank=True)
    elevation = models.IntegerField (null=True, blank=True)
    gtopo30 = models.IntegerField (null=True, blank=True)
    timezone = models.CharField (max_length=40, null=True, blank=True)
    moddate = models.DateField ('modification date', null=True, blank=True)
    def __unicode__(self):
        return '%s, %s (%d, %d)' % (self.name, self.country, 
                                    self.latitude, self.longitude)

    class Meta:
        db_table = 'geoname'

# Class corresponding to the alternate_name database table, linked to the
# geoname table
class AlternateName (models.Model):
    alternatenameid = models.IntegerField (db_column='alternatenameid',
                                           primary_key=True)
    geonameid = models.ForeignKey (POR, db_column='geonameid', null=True)
    isoLanguage = models.CharField (max_length=7, null=True, blank=True)
    alternateName = models.CharField (max_length=200, null=True, blank=True)
    isPreferredName = models.PositiveSmallIntegerField (null=True, blank=True)
    isShortName = models.PositiveSmallIntegerField (null=True, blank=True)
    def __unicode__(self):
        # The POR name can be accessed thanks to self.geonameid.name
        return '%s, %s' % (self.isoLanguage, self.alternateName)

    class Meta:
        db_table = 'alternate_name'




import os, sys, setuptools
from skbuild import setup

with open("README.md", "r") as fh:
    long_description = fh.read()

setup (
    name='opentrep',
    version='0.7.6-1',
    author='Denis Arnaud',
    author_email='denis.arnaud_pypi@m4x.org',
    description=('''Simple Python wrapper for OpenTREP'''),
    license='MIT',
    keywords='api python trep opentrep package',
    url='https://github.com/trep/opentrep',
    packages=setuptools.find_packages(),
    long_description=long_description,
    long_description_content_type="text/markdown",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    cmake_args = [
      '-DINSTALL_DOC:BOOL=OFF',
      '-DRUN_GCOV:BOOL=OFF',
      '-DLIB_SUFFIX='
      ] + (
      ['-DREADLINE_ROOT=/usr/local/opt/portable-readline',
       '-DREADLINE_INCLUDE_DIR=/usr/local/opt/portable-readline/include',
       '-DREADLINE_LIBRARY=/usr/local/opt/libedit/lib/libedit.dylib',
       '-DICU_ROOT=/usr/local/opt/icu4c'] if sys.platform.startswith("darwin") else []
      )
)




from django.conf.urls.defaults import *
from django.contrib import admin
admin.autodiscover()

urlpatterns = patterns('',
    # Map ^trep to api/urls.py (api.urls module)
    (r'^trep/api/', include ('api.urls')),

    # Map ^test to test/views.py (test module)
    (r'^trep/test/', 'test.views.myview'),

    # Uncomment the admin/doc line below to enable admin documentation:
    (r'^trep/admin/doc/', include ('django.contrib.admindocs.urls')),

    # Uncomment the next line to enable the admin:
    (r'^trep/admin/', include (admin.site.urls)),
)




#!/usr/bin/env python

#
from geonames.models import POR, AlternateName

# Retrieving the Geonames entries for a few airports
nice_airport = POR.objects.get (geonameid=6299418)
kiev_airport = POR.objects.get (geonameid=6300952)
# And their related names
#nice_names = AlternateName.objects.filter (geonameid=6299418)
nice_names = nice_airport.alternatename_set.all()
#kiev_names = AlternateName.objects.filter (geonameid=6300952)
kiev_names = kiev_airport.alternatename_set.all()

#
print 'Nice airport: ', nice_airport, nice_names
print 'Kiev (Boryspil) airport: ', kiev_airport, kiev_names


